@@ -1,3 +1,4 @@
+from __future__ import annotations
 import torch
 import torch.nn as nn
 import numpy as np
@@ -5,7 +6,7 @@ import abc
 import pytomography
 from pytomography.metadata import ObjectMeta, ImageMeta
 
-class Prior(nn.Module):
+class Prior():
     r"""Abstract class for implementation of prior :math:`V(f)` where :math:`V` is from the log-posterior probability :math:`\ln L(\tilde{f}, f) - \beta V(f)`. Any function inheriting from this class should implement a ``foward`` method that computes the tensor :math:`\frac{\partial V}{\partial f_r}` where :math:`f` is an object tensor.
     
     Args:
@@ -13,11 +14,10 @@ class Prior(nn.Module):
             device (float): Pytorch device used for computation. Defaults to 'cpu'.
     """
     @abc.abstractmethod
-    def __init__(self, beta: float, device : str = None):
-        super(Prior, self).__init__()
+    def __init__(self, beta: float):
         self.beta = beta
         self.beta_scale_factor = 1
-        self.device = pytomography.device if device is None else device
+        self.device = pytomography.device
 
     def set_object_meta(self, object_meta: ObjectMeta) -> None:
         """Sets object metadata parameters.
@@ -43,16 +43,8 @@ class Prior(nn.Module):
         """
         self.object = object
 
-    def set_device(self, device: str) -> None:
-        """Sets the pytorch computation device
-
-        Args:
-            device (str): sets device.
-        """
-        self.device=device
-
     @abc.abstractmethod
-    def forward(self):
+    def __call__(self):
         """Abstract method to compute prior based on the ``self.object`` attribute.
         """
         ...
\ No newline at end of file
